import 'package:flutter/material.dart';

//定义扩展方便获取到颜色值
extension ThemeDataExtension on ThemeData {
  AppColorsTheme get appColors => extension<AppColorsTheme>()!;
}

extension AppColorsThemeExtensions on BuildContext {
  AppColorsTheme get appColors => Theme.of(this).extension<AppColorsTheme>()!;
}

class AppColorsTheme extends ThemeExtension<AppColorsTheme> {
  //亮色主题的自定义颜色值
  static const _colorB0B0B0 = Color(0xFFB0B0B0);
  static const _color6C6C6C = Color(0xFF6C6C6C);
  static const _colorF9F9F9 = Color(0xffF9F9F9);

  //暗色主题的一些自定义颜色值
  static const _darkBlackBg = Color(0xFF0F0F0F);
  static const _darkBlackItem = Color(0xFF1D1D1E);
  static const _darkBlackItemLight = Color(0xFF3B3933);
  static const _darkBlackItemLightMost = Color(0xFF5C5850);
  static const _darkBlackItemDivider = Color(0xFF3B3B3F);

  // 页面中真正使用到的颜色名称
  final Color backgroundDefault; //动态颜色
  final Color btnBgDefault;


  // 私有的构造函数
  const AppColorsTheme._internal({
    required this.backgroundDefault,
    required this.btnBgDefault,
  });

  // 浅色主题工厂方法
  factory AppColorsTheme.light() {
    return const AppColorsTheme._internal(
      backgroundDefault: _colorF9F9F9,
      btnBgDefault: Colors.deepPurple,
    );
  }

  // 暗色主题工厂方法
  factory AppColorsTheme.dark() {
    return const AppColorsTheme._internal(
      backgroundDefault: _darkBlackBg,
      btnBgDefault: _darkBlackItem,
    );
  }

  @override
  ThemeExtension<AppColorsTheme> copyWith({bool? lightMode}) {
    if (lightMode == null || lightMode == true) {
      return AppColorsTheme.light();
    }
    return AppColorsTheme.dark();
  }

  @override
  AppColorsTheme lerp(covariant ThemeExtension<AppColorsTheme>? other, double t) {
    if (other is! AppColorsTheme) return this;
    return AppColorsTheme._internal(
      backgroundDefault: Color.lerp(backgroundDefault, other.backgroundDefault, t)!,
      btnBgDefault: Color.lerp(btnBgDefault, other.btnBgDefault, t)!,
    );
  }
}
